*****************************************************************************************
* Master do-file : PRISE - Cote d'Ivoire                                            *
****************************************************************************************

* Author: Alicia Marguerie, Horacio Vera, Daniel Corredor 
* Last update : March 14, 2025 


*Data: endline and baseline data for PRISE, individual level data.
*Source of data : 
	*Electronic data collected by BCPE, on CAPI (WB)

/*
	Master do file organization :

		1/ Initialization: user paths and global macro for paths
	    2/ Data processing of raw data (baseline and endline)
		3/ Data analysis: Tables and figures of the paper
*/



*========================================================================================================================
*      1 /  INITIALIZATION
*========================================================================================================================

	clear all
	set maxvar 	10000
	capture log close
	set matsize 1600
	set logtype text
	set dp period
	set more off


**** insert the folder path in the global below.
global reproducibility_folder  ""


global data="$reproducibility_folder/data"
global dofile="$reproducibility_folder/code" 
global output="$reproducibility_folder/Outputs" 
		

		sysdir set PLUS "${reproducibility_folder}/ado"
		
		cd "$reproducibility_folder"	
		
	

* setting ado folder   
	
    *ssc install ietoolkit
   	ieboilstart, version(14)
	`r(version)'
	/*
	 foreach pkg in tabstatmat ///
	                outreg2 ///
	                estout ///
	                outtable	///
					ietoolkit	///
					estout		///
					rwolf2		///
					kdens		///
					mhtreg		///	
					pdslasso	///
					qqvalue 	///
					texdoc      ///
					touch		///
	{
		capture which `pkg' 
		if _rc==111 ssc install `pkg'
	}	

	capture findfile lmoremata.mlib
	if _rc==601 ssc install moremata

	capture which lasso2
	if _rc==111 ssc install lassopack
	
    capture which zscore
	if _rc!=0 net install zscore, from("http://www.stata.com/users/sdriver/")
	
	
	capture which outreg
	if _rc==111 net install sg97_5.pkg, from("http://www.stata-journal.com/software/sj12-4")
    
	capture which matdelrc
	if _rc==111 net install dm69.pkg, from("http://www.stata.com/stb/stb50/")
    */
	version 17.0
	set varabbrev on
	
	


* <<<<<<<<<<<<<<<<<< End INITIALIZATION --------------------------------------------



*========================================================================================================================
*      2 /  DATA PROCESSING (CLEANING AND VARIABLE CREATION)
*========================================================================================================================

** Clean baseline 
do "$dofile/cleaning and var creation/baseline_data_cleaning_code.do"

** Clean endline
*do "$dofile/Preparing endline dataset/Preparing_endline_dataset.do"	
do "$dofile/cleaning and var creation/endline_data_cleaning_code.do"

***** Set the lasso controls for baseline 
do "$dofile/cleaning and var creation/baseline_controls_for_lasso.do"
********************************************************************************






*========================================================================================================================
*      3 /  DATA ANALYSIS
*========================================================================================================================

// *========================================================================================================================
// *       /  BALANCE TABLES
// *========================================================================================================================	

do "$dofile/analysis/baseline_analysis_do_file.do"	
		
// *========================================================================================================================
// *       /  ENDLINE ESTIMATIONS
// *========================================================================================================================

do "$dofile/analysis/endline analysis/Endline_analysis_master_do_file.do"	



	
		